==> kpackagekit_0.4.2.orig.tar.gz: kpackagekit-0.4.2/libkpackagekit/KpkRequirements.h <==
/***************************************************************************
 *   Copyright (C) 2008-2009 by Daniel Nicoletti                           *
 *   dantti85-pk@yahoo.com.br                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef KPKREQUIREMENTS_H
#define KPKREQUIREMENTS_H

#include <KDialog>

#include "KpkSimplePackageModel.h"

using namespace PackageKit;

class KpkRequirementsPrivate;

class KDE_EXPORT KpkRequirements : public KDialog
{
    Q_OBJECT
public:
    KpkRequirements(QString msg, KpkSimplePackageModel *model, QWidget *parent = 0);
    ~KpkRequirements();

private:
    KpkRequirementsPrivate *d;
};

#endif

==> kpackagekit_0.5.4.orig.tar.gz: kpackagekit-0.5.4/libkpackagekit/KpkRequirements.h <==
/***************************************************************************
 *   Copyright (C) 2008-2009 by Daniel Nicoletti                           *
 *   dantti85-pk@yahoo.com.br                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef KPKREQUIREMENTS_H
#define KPKREQUIREMENTS_H

#include <KDialog>

#include "KpkSimulateModel.h"

using namespace PackageKit;

class KpkRequirementsPrivate;

class KDE_EXPORT KpkRequirements : public KDialog
{
    Q_OBJECT
public:
    KpkRequirements(KpkSimulateModel *model, QWidget *parent = 0);
    ~KpkRequirements();

private slots:
    void actionClicked(const QModelIndex &index);

private:
    KpkRequirementsPrivate *d;
};

#endif
